@@ -166,17 +166,17 @@ pub fn read_check_file(file_name: &str,is_status:bool) -> Result<Vec <CheckFileI
     let mut result: Vec <CheckFileInfo> = Vec::new();
     for r_line in buffered.lines() {
         let line : String = r_line.unwrap();
-        let tokens : Vec<&str> = line.split_whitespace().collect();
+        let tokens : Vec<&str> = line.rsplit(' ').collect();
         //println!("{:?}",tokens);
         match tokens.len() {
             2 => {
-                let hash = tokens.get(0).unwrap().to_string();
-                let mode = if tokens.get(1).unwrap().starts_with('*') {Mode::Binary} else { Mode::Text };
+                let hash = tokens.get(1).unwrap().to_string();
+                let mode = if tokens.get(0).unwrap().starts_with('*') {Mode::Binary} else { Mode::Text };
                 let file = match mode {
-                    Mode::Binary => tokens.get(1).unwrap().trim_start_matches('*'),
+                    Mode::Binary => tokens.get(0).unwrap().trim_start_matches('*'),
                     _=> tokens.get(1).unwrap(),
                 };
-                let algorithm  = match tokens.get(0).unwrap().len() {
+                let algorithm  = match tokens.get(1).unwrap().len() {
                     56 => Ok(Sha3Mode::Sha3_224),
                     64 => Ok(Sha3Mode::Sha3_256),
                     96 => Ok(Sha3Mode::Sha3_384),
@@ -198,11 +198,11 @@ pub fn read_check_file(file_name: &str,is_status:bool) -> Result<Vec <CheckFileI
             },
             4 => {
                 let s_line = CheckFileInfo {
-                    algorithm: Sha3Mode::from(tokens.get(0).unwrap().to_string()),
+                    algorithm: Sha3Mode::from(tokens.get(3).unwrap().to_string()),
                     mode: Mode::Binary,
                     is_bsd_format: true,
-                    hash: tokens.get(3).unwrap().to_string(),
-                    file_name: tokens.get(1).unwrap().trim_start_matches('(').trim_end_matches(')').to_string(),
+                    hash: tokens.get(0).unwrap().to_string(),
+                    file_name: tokens.get(2).unwrap().trim_start_matches('(').trim_end_matches(')').to_string(),
                 };
                 //println!("{:?}",s_line);
                 result.push(s_line);
@@ -448,7 +448,7 @@ mod tests {
     fn test_read_check_file() {
         let result = read_check_file(CHECK_FILE,false);
         assert!(result.is_ok());
-        assert_eq!(result.unwrap().len(),6);
+        assert_eq!(result.unwrap().len(),10);
     }
 
     #[test]
